@@ -491,7 +491,7 @@ def createQEAxes(DataSet=None,axis=0,figure = None, projectionVector1 = None, pr
     if projectionVector1 is None or projectionVector2 is None:
         if rlu is True:
             v1 = DataSet.sample[0].projectionVector1
-            v2 = DataSet.sample[0].projectionVector2
+            v2 = -DataSet.sample[0].projectionVector2
             angle = DataSet.sample[0].projectionAngle
             orientationMatrix = DataSet.sample[0].orientationMatrix
         else:
@@ -595,7 +595,6 @@ def createQEAxes(DataSet=None,axis=0,figure = None, projectionVector1 = None, pr
     ax.format_coord = lambda x,y: format_coord(*ax.calculateRLU(x,y))
 
 
-
     ax.forceGridUpdate = lambda:forceGridUpdate(ax)
     ax.xticks = 7
 
